@@ -1,8 +1,7 @@
-from collections import defaultdict
-
-from django.db.models import get_model
-from django.db.models import Q
+from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
+from django.db.models import Q
+
 
 from actstream.gfk import GFKManager
 from actstream.decorators import stream
@@ -56,9 +55,9 @@ class ActionManager(GFKManager):
         check(model)
         ctype = ContentType.objects.get_for_model(model)
         return self.public(
-            (Q(target_content_type=ctype) |
-             Q(action_object_content_type=ctype) |
-             Q(actor_content_type=ctype)),
+            (Q(target_content_type=ctype)
+             | Q(action_object_content_type=ctype)
+             | Q(actor_content_type=ctype)),
             **kwargs
         )
 
@@ -82,11 +81,8 @@ class ActionManager(GFKManager):
             ), **kwargs)
 
     @stream
-    def user(self, obj, **kwargs):
-        """
-        Stream of most recent actions by objects that the passed User obj is
-        following.
-        """
+    def user(self, obj, with_user_activity=False, follow_flag=None, **kwargs):
+        """Create a stream of the most recent actions by objects that the user is following."""
         q = Q()
         qs = self.public()
 
@@ -94,38 +90,39 @@ class ActionManager(GFKManager):
             return qs.none()
 
         check(obj)
-        actors_by_content_type = defaultdict(lambda: [])
-        others_by_content_type = defaultdict(lambda: [])
 
-        if kwargs.pop('with_user_activity', False):
-            object_content_type = ContentType.objects.get_for_model(obj)
-            actors_by_content_type[object_content_type.id].append(obj.pk)
+        if with_user_activity:
+            q = q | Q(
+                actor_content_type=ContentType.objects.get_for_model(obj),
+                actor_object_id=obj.pk
+            )
 
-        follow_gfks = get_model('actstream', 'follow').objects.filter(
-            user=obj).values_list('content_type_id',
-                                  'object_id', 'actor_only')
+        follows = apps.get_model('actstream', 'follow').objects.filter(user=obj)
+        if follow_flag:
+            follows = follows.filter(flag=follow_flag)
 
-        for content_type_id, object_id, actor_only in follow_gfks.iterator():
-            actors_by_content_type[content_type_id].append(object_id)
-            if not actor_only:
-                others_by_content_type[content_type_id].append(object_id)
+        content_types = ContentType.objects.filter(
+            pk__in=follows.values('content_type_id')
+        )
 
-        if len(actors_by_content_type) + len(others_by_content_type) == 0:
+        if not (content_types.exists() or with_user_activity):
             return qs.none()
 
-        for content_type_id, object_ids in actors_by_content_type.items():
+        for content_type in content_types:
+            object_ids = follows.filter(content_type=content_type)
             q = q | Q(
-                actor_content_type=content_type_id,
-                actor_object_id__in=object_ids,
-            )
-        for content_type_id, object_ids in others_by_content_type.items():
-            q = q | Q(
-                target_content_type=content_type_id,
-                target_object_id__in=object_ids,
+                actor_content_type=content_type,
+                actor_object_id__in=object_ids.values('object_id')
             ) | Q(
-                action_object_content_type=content_type_id,
-                action_object_object_id__in=object_ids,
+                target_content_type=content_type,
+                target_object_id__in=object_ids.filter(
+                    actor_only=False).values('object_id')
+            ) | Q(
+                action_object_content_type=content_type,
+                action_object_object_id__in=object_ids.filter(
+                    actor_only=False).values('object_id')
             )
+
         return qs.filter(q, **kwargs)
 
 
@@ -134,36 +131,52 @@ class FollowManager(GFKManager):
     Manager for Follow model.
     """
 
-    def for_object(self, instance):
+    def for_object(self, instance, flag=''):
         """
         Filter to a specific instance.
         """
         check(instance)
         content_type = ContentType.objects.get_for_model(instance).pk
-        return self.filter(content_type=content_type, object_id=instance.pk)
+        queryset = self.filter(content_type=content_type, object_id=instance.pk)
+        if flag:
+            queryset = queryset.filter(flag=flag)
+        return queryset
 
-    def is_following(self, user, instance):
+    def is_following(self, user, instance, flag=''):
         """
         Check if a user is following an instance.
         """
-        if not user or user.is_anonymous():
+        if not user or user.is_anonymous:
             return False
         queryset = self.for_object(instance)
+
+        if flag:
+            queryset = queryset.filter(flag=flag)
         return queryset.filter(user=user).exists()
 
-    def followers(self, actor):
+    def followers_qs(self, actor, flag=''):
+        """
+        Returns a queryset of User objects who are following the given actor (eg my followers).
+        """
+        check(actor)
+        queryset = self.filter(
+            content_type=ContentType.objects.get_for_model(actor),
+            object_id=actor.pk
+        ).select_related('user')
+
+        if flag:
+            queryset = queryset.filter(flag=flag)
+        return queryset
+
+    def followers(self, actor, flag=''):
         """
         Returns a list of User objects who are following the given actor (eg my followers).
         """
-        check(actor)
-        return [follow.user for follow in self.filter(
-            content_type=ContentType.objects.get_for_model(actor),
-            object_id=actor.pk
-        ).select_related('user')]
+        return [follow.user for follow in self.followers_qs(actor, flag=flag)]
 
-    def following(self, user, *models):
+    def following_qs(self, user, *models, **kwargs):
         """
-        Returns a list of actors that the given user is following (eg who im following).
+        Returns a queryset of actors that the given user is following (eg who im following).
         Items in the list can be of any model unless a list of restricted models are passed.
         Eg following(user, User) will only return users following the given user
         """
@@ -173,4 +186,19 @@ class FollowManager(GFKManager):
             check(model)
             ctype_filters |= Q(content_type=ContentType.objects.get_for_model(model))
         qs = qs.filter(ctype_filters)
-        return [follow.follow_object for follow in qs.fetch_generic_relations('follow_object')]
+
+        flag = kwargs.get('flag', '')
+
+        if flag:
+            qs = qs.filter(flag=flag)
+        return qs.fetch_generic_relations('follow_object')
+
+    def following(self, user, *models, **kwargs):
+        """
+        Returns a list of actors that the given user is following (eg who im following).
+        Items in the list can be of any model unless a list of restricted models are passed.
+        Eg following(user, User) will only return users following the given user
+        """
+        return [follow.follow_object for follow in self.following_qs(
+            user, *models, flag=kwargs.get('flag', '')
+        )]
