@@ -1,47 +1,47 @@
-import django
+from __future__ import unicode_literals
+
+from django.conf import settings
+from django.contrib.contenttypes.fields import GenericForeignKey
 from django.db import models
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext as _
-from django.utils.encoding import python_2_unicode_compatible
+from django.utils.translation import gettext as _
 from django.utils.timesince import timesince as djtimesince
 from django.contrib.contenttypes.models import ContentType
-
-
-try:
-    from django.utils import timezone
-    now = timezone.now
-except ImportError:
-    from datetime import datetime
-    now = datetime.now
+from django.urls import reverse
+from django.utils.timezone import now
 
 from actstream import settings as actstream_settings
 from actstream.managers import FollowManager
-from actstream.compat import user_model_label, generic
 
 
-@python_2_unicode_compatible
 class Follow(models.Model):
     """
     Lets a user follow the activities of any specific actor
     """
-    user = models.ForeignKey(user_model_label)
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL, on_delete=models.CASCADE, db_index=True
+    )
 
-    content_type = models.ForeignKey(ContentType)
-    object_id = models.CharField(max_length=255)
-    follow_object = generic.GenericForeignKey()
-    actor_only = models.BooleanField("Only follow actions where "
-                                     "the object is the target.", default=True)
-    started = models.DateTimeField(default=now)
+    content_type = models.ForeignKey(
+        ContentType, on_delete=models.CASCADE, db_index=True
+    )
+    object_id = models.CharField(max_length=255, db_index=True)
+    follow_object = GenericForeignKey()
+    actor_only = models.BooleanField(
+        "Only follow actions where "
+        "the object is the target.",
+        default=True
+    )
+    flag = models.CharField(max_length=255, blank=True, db_index=True, default='')
+    started = models.DateTimeField(default=now, db_index=True)
     objects = FollowManager()
 
     class Meta:
-        unique_together = ('user', 'content_type', 'object_id')
+        unique_together = ('user', 'content_type', 'object_id', 'flag')
 
     def __str__(self):
-        return '%s -> %s' % (self.user, self.follow_object)
+        return '{} -> {} : {}'.format(self.user, self.follow_object, self.flag)
 
 
-@python_2_unicode_compatible
 class Action(models.Model):
     """
     Action model describing the actor acting out a verb (on an optional
@@ -71,33 +71,50 @@ class Action(models.Model):
         <a href="http://oebfare.com/">brosner</a> commented on <a href="http://github.com/pinax/pinax">pinax/pinax</a> 2 hours ago
 
     """
-    actor_content_type = models.ForeignKey(ContentType, related_name='actor')
-    actor_object_id = models.CharField(max_length=255)
-    actor = generic.GenericForeignKey('actor_content_type', 'actor_object_id')
+    actor_content_type = models.ForeignKey(
+        ContentType, related_name='actor',
+        on_delete=models.CASCADE, db_index=True
+    )
+    actor_object_id = models.CharField(max_length=255, db_index=True)
+    actor = GenericForeignKey('actor_content_type', 'actor_object_id')
 
-    verb = models.CharField(max_length=255)
+    verb = models.CharField(max_length=255, db_index=True)
     description = models.TextField(blank=True, null=True)
 
-    target_content_type = models.ForeignKey(ContentType, blank=True, null=True,
-                                            related_name='target')
-    target_object_id = models.CharField(max_length=255, blank=True, null=True)
-    target = generic.GenericForeignKey('target_content_type',
-                                       'target_object_id')
+    target_content_type = models.ForeignKey(
+        ContentType, blank=True, null=True,
+        related_name='target',
+        on_delete=models.CASCADE, db_index=True
+    )
+    target_object_id = models.CharField(
+        max_length=255, blank=True, null=True, db_index=True
+    )
+    target = GenericForeignKey(
+        'target_content_type',
+        'target_object_id'
+    )
 
-    action_object_content_type = models.ForeignKey(ContentType, blank=True, null=True,
-                                                   related_name='action_object')
-    action_object_object_id = models.CharField(max_length=255, blank=True, null=True)
-    action_object = generic.GenericForeignKey('action_object_content_type',
-                                              'action_object_object_id')
+    action_object_content_type = models.ForeignKey(
+        ContentType, blank=True, null=True,
+        related_name='action_object',
+        on_delete=models.CASCADE, db_index=True
+    )
+    action_object_object_id = models.CharField(
+        max_length=255, blank=True, null=True, db_index=True
+    )
+    action_object = GenericForeignKey(
+        'action_object_content_type',
+        'action_object_object_id'
+    )
 
-    timestamp = models.DateTimeField(default=now)
+    timestamp = models.DateTimeField(default=now, db_index=True)
 
-    public = models.BooleanField(default=True)
+    public = models.BooleanField(default=True, db_index=True)
 
     objects = actstream_settings.get_action_manager()
 
     class Meta:
-        ordering = ('-timestamp', )
+        ordering = ('-timestamp',)
 
     def __str__(self):
         ctx = {
@@ -141,11 +158,11 @@ class Action(models.Model):
         Shortcut for the ``django.utils.timesince.timesince`` function of the
         current timestamp.
         """
-        return djtimesince(self.timestamp, now).encode('utf8').replace(b'\xc2\xa0', b' ').decode()
+        return djtimesince(self.timestamp, now).encode('utf8').replace(b'\xc2\xa0', b' ').decode('utf8')
 
-    @models.permalink
     def get_absolute_url(self):
-        return 'actstream.views.detail', [self.pk]
+        return reverse(
+            'actstream_detail', args=[self.pk])
 
 
 # convenient accessors
@@ -157,9 +174,3 @@ model_stream = Action.objects.model_actions
 any_stream = Action.objects.any
 followers = Follow.objects.followers
 following = Follow.objects.following
-
-
-if django.VERSION[:2] < (1, 7):
-    from actstream.apps import ActstreamConfig
-
-    ActstreamConfig().ready()
